.. include:: ../BADGES.rst

Notebooks
=========

.. toctree::
    :maxdepth: 1

    ../notebooks/tstoolbox_statistics_python
    ../notebooks/tstoolbox_filling_python
    ../notebooks/tstoolbox_plot_bash
